@@ -7,10 +7,11 @@ use Cwd;
 
 eval { require "$FindBin::Bin/../lib/perl5/site_perl/Envy/DB.pm" }
   if !defined $ {"Envy::DB::VERSION"};
-eval { require Envy::DB }
-  if !defined $ {"Envy::DB::VERSION"};
 eval { require "$FindBin::Bin/../lib/Envy/DB.pm" } #blib
   if !defined $ {"Envy::DB::VERSION"};
+eval { require Envy::DB }
+  if !defined $ {"Envy::DB::VERSION"};
+
 die "Can't find Envy::DB: $@"
   if !defined $ {"Envy::DB::VERSION"};
 
@@ -70,6 +71,7 @@ sub GO() {
     if ($cmd eq "load" or $cmd eq "reload" or $cmd eq "show") {
 	&HELP if @ARGV < 1;
 	$is_showing = $cmd eq 'show';
+	$db->do_log(!$is_showing);
 	while (@ARGV) {
 	    $db->do_envy(shift @ARGV, 0);
 	}
@@ -79,11 +81,7 @@ sub GO() {
 	my ($ign, $loaded) = $db->status();
 	push(@ARGV, 'all') if @ARGV == 0;
 	if (@ARGV == 1 and $ARGV[0] eq 'all') {
-	    for my $phase (1..2) {
-		for my $m ($db->to_unload($phase)) {
-		    $db->do_envy($m, 1) if !$db->is_unloaded($m);
-		}
-	    }
+	    $db->unload_all();
 	} else {
 	    while (@ARGV) { $db->do_envy(shift @ARGV, 1); }
 	}
@@ -101,7 +99,7 @@ sub GO() {
 	print "All envys currently available ($Envy::DB::VERSION):\n\n";
 	for my $m (@mo) {
 	    my $file = $mo->{$m};
-	    while (-l $file) { $file = readlink($file) or die "readlink: $!" }
+#	    while (-l $file) { $file = readlink($file) or die "readlink: $!" }
 	    print $loaded{$m}? " x ":"   ";
 	    print $m . ' 'x(1 + $l - length $m) . $file . "\n";
 	}
@@ -122,6 +120,7 @@ sub GO() {
 	if (@mo == 0) {
 	    print "Envy '$cmd' not found.\n";
 	} elsif (@mo == 1) {
+	    $db->fuzzy(1);
 	    $db->do_envy(shift @mo, 0);
 	    sync_env($db);
 	    return;
@@ -170,8 +169,8 @@ sub HELP {
 
    JAVA_HOME=/nw/prod/usr            # Sets environment variable.
    PATH+=/nw/prod/odi/osji/5.0/bin   # Prepended to colin separated list.
-   TOP=\$ENVY_BASE                    # Real path to envy without etc/envy/.
-   TOP=\$ENVY_LINKBASE                # Path to envy without etc/envy/.
+   MYTOP=\$ENVY_BASE                  # Real path to envy without etc/envy/.
+   MYTOP=\$ENVY_LINKBASE              # Path to envy without etc/envy/.
 
 3] ENVIRONMENT VARIABLES
 
